%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%
% SIIT Exam Class
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{siitexam}[2014/05/20 v1.0 SIIT Exam]
% Developed by Steven Gordon
% http://sandilands.info/sgordon/
% $Revision: 854 $
% $Date: 2010-12-02 18:26:52 +0700 (Thu, 02 Dec 2010) $
% $Author: sgordon $
% $URL: https://sandilands.info/svn/Common/Styles/siitassess/siitexam.cls $

% Use the article class
\LoadClass[12pt,onecolumn,twoside,a4paper]{article}

% Required packages
\RequirePackage{fancyhdr} % Needed for headers and footers
\RequirePackage{qvariants} % Needed for question variants

% Page layout (25mm margins around text)
\setlength{\hoffset}{-2mm}
\setlength{\voffset}{-12mm}
\setlength{\oddsidemargin}{0mm}
\setlength{\evensidemargin}{0mm}
\setlength{\topmargin}{0mm}
\setlength{\textheight}{246mm}
\setlength{\textwidth}{159mm}
\setlength{\marginparsep}{2mm}
\setlength{\marginparwidth}{20mm}
\setlength{\headheight}{6mm}
\setlength{\headsep}{6mm}


% Set the counters to appropriate format for questions and subquestions
\renewcommand{\thesection}{Question \arabic{section}}
\renewcommand{\labelenumi}{(\alph{enumi})}
\renewcommand{\labelenumii}{\roman{enumii}.}

% Question numbering
\newcommand{\question}[1]{\section{\textmd{[#1 marks]}}}
\newcommand{\mcquestion}[1]{%
\renewcommand{\thesection}{Multiple Choice Questions}
\renewcommand{\labelenumi}{\arabic{enumi}.}
\renewcommand{\labelenumii}{(\alph{enumii})}
\section{\textmd{[#1 marks]}}}

% Exam instructions (to be edited in .tex file)
\newcommand{\examinstructions}[1]{}

% Document information
\newcommand{\docversion}[1]{\def\@docversion{#1}}
\newcommand{\docnumber}[1]{\def\@docnumber{#1}}
\newcommand{\docfile}[1]{\def\@docfile{#1}}
\newcommand{\docdate}[1]{\def\@docdate{#1}}
\newcommand{\instructor}[1]{\def\@instructor{#1}}
\newcommand{\exam}[1]{\def\@exam{#1}}
\newcommand{\coursecode}[1]{\def\@coursecode{#1}}
\newcommand{\coursetitle}[1]{\def\@coursetitle{#1}}
\newcommand{\courseshort}[1]{\def\@courseshort{#1}}
\newcommand{\semester}[1]{\def\@semester{#1}}
\newcommand{\academicyear}[1]{\def\@academicyear{#1}}
\newcommand{\testdate}[1]{\def\@testdate{#1}}

% Some commonly used phrases/names
\newcommand{\siit}{Sirindhorn International Institute of Technology}
\newcommand{\tu}{Thammasat University}

% Title page
\renewcommand{\maketitle}{%

% Header/footer for title page
\pagestyle{fancy}
\fancyhead{}
\fancyfoot{}
\fancyhead[LO,LE]{Name \ldots\ldots\ldots\ldots\ldots\ldots\ldots\ldots\ldots\ldots $\;$ ID  \ldots\ldots\ldots\ldots\ldots $\;$ Section \ldots\ldots $\;$ Seat No \ldots\ldots}
\fancyhead[RO,RE]{}
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}

% The title page
\begin{center}
{\Large\textbf{\siit}}\\
\vspace*{2mm}
{\Large\textbf{\tu}}\\
\vspace*{5mm}
{\textbf{\@exam: Semester \@semester, \@academicyear}}\\
\end{center}
\begin{description}
\item[Course Title:] \@coursecode\ \@coursetitle
\item[Instructor:] \@instructor
\item[Date/Time:] \@testdate
\end{description}
\hrule
\paragraph{Instructions:}
\examinstructions
\newpage

% Header/foot for rest of document
\pagestyle{fancy}
\fancyhead{}
\fancyfoot{}
\fancyhead[LO,LE]{\itshape\footnotesize{\siit}}
\fancyhead[RO,RE]{\itshape\footnotesize{\@coursecode}}
\fancyfoot[LO,LE]{\itshape\footnotesize{\@courseshort}}
\fancyfoot[CO,CE]{\itshape\footnotesize{}}
\fancyfoot[RO,RE]{\itshape\footnotesize{\thepage}}
\renewcommand{\headrulewidth}{0.4pt}
\renewcommand{\footrulewidth}{0.4pt}
}

% Summary document information
\newcommand{\docinfo}{%
\begin{center}
\vspace*{2mm}
\@coursetitle, Semester \@semester, \@academicyear\\
\vspace*{2mm}
\footnotesize{Prepared by \@instructor\ on \@docdate}\\
\footnotesize{\@docnumber, \@docfile, r\@docversion}
\end{center}
}


