%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%
% SIIT Quiz Class
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{siitquiz}[2014/05/20 v1.0 SIIT Quiz]
% Developed by Steven Gordon
% http://sandilands.info/sgordon/
% $Revision: 854 $
% $Date: 2014-05-20 14:21:42 +0700 (Tue, 20 May 2014) $
% $Author: sgordon $
% $URL: https://sandilands.info/svn/Common/Styles/siitassess/siitquiz.cls $

% Use article class
\LoadClass[12pt,onecolumn,twoside,a4paper]{article}

% Required packages
\RequirePackage{fancyhdr} % Needed for headers and footers
\RequirePackage{qvariants} % Needed for question variants

% Page layout (25mm margins around text)
\setlength{\hoffset}{-2mm}
\setlength{\voffset}{-12mm}
\setlength{\oddsidemargin}{0mm}
\setlength{\evensidemargin}{0mm}
\setlength{\topmargin}{0mm}
\setlength{\textheight}{246mm}
\setlength{\textwidth}{159mm}
\setlength{\marginparsep}{2mm}
\setlength{\marginparwidth}{20mm}
\setlength{\headheight}{6mm}
\setlength{\headsep}{6mm}

% Document information
\newcommand{\doctitle}[1]{\def\@doctitle{#1}}
\newcommand{\doctitleabbrev}[1]{\def\@doctitleabbrev{#1}}
\newcommand{\docauthor}[1]{\def\@docauthor{#1}}
\newcommand{\docnumber}[1]{\def\@docnumber{#1}}
\newcommand{\doccategory}[1]{\def\@doccategory{#1}}
\newcommand{\docversion}[1]{\def\@docversion{#1}}
\newcommand{\docfile}[1]{\def\@docfile{#1}}
\newcommand{\docdate}[1]{\def\@docdate{#1}}
\newcommand{\coursecode}[1]{\def\@coursecode{#1}}
\newcommand{\coursetitle}[1]{\def\@coursetitle{#1}}
\newcommand{\semester}[1]{\def\@semester{#1}}
\newcommand{\academicyear}[1]{\def\@academicyear{#1}}
\newcommand{\testdate}[1]{\def\@testdate{#1}}

% Some commonly used phrases/names
\newcommand{\siit}{Sirindhorn International Institute of Technology}
\newcommand{\tu}{Thammasat University}

% Max marks
\newcommand{\maxmarks}{10}

% Document info 
\newcommand{\docinfo}{%
\begin{center}
\vspace*{2mm}
\@coursetitle, Semester \@semester, \@academicyear\\
\vspace*{2mm}
\footnotesize{Prepared by \@docauthor\ on \@docdate}\\
\footnotesize{\@docnumber, \@docfile, r\@docversion}
\end{center}
}

% Display student name, ID and mark (giving max mark as input)
\newcommand{\studentname}[1]{%
\begin{center}
\begin{picture}(450,30)
\put(0,10){\mbox{Name:}}
\put(35,10){\line(1,0){160}}
\put(215,10){\mbox{ID:}}
\put(235,10){\line(1,0){100}}
\put(355,10){\mbox{Marks:}}
\put(395,10){\line(1,0){30}}
\put(430,10){\mbox{(#1)}}
\end{picture}
\end{center}
}

% Page Headers 
\pagestyle{fancy}
\fancyhead{}
\fancyfoot{}
\fancyhead[LO,LE]{\itshape\footnotesize{\siit}}
\fancyhead[RO,RE]{\itshape\footnotesize{\@coursecode}}
\fancyfoot[LO,LE]{\itshape\footnotesize{\@doctitleabbrev}}
\fancyfoot[CO,CE]{\itshape\footnotesize{\@docdate}}
\fancyfoot[RO,RE]{\itshape\footnotesize{\thepage}}
\renewcommand{\headrulewidth}{0.4pt}
\renewcommand{\footrulewidth}{0.4pt}

% Set the counters to appropriate format for questions and subquestions
\renewcommand{\thesection}{Question \arabic{section}}
\renewcommand{\labelenumi}{(\alph{enumi})}
\renewcommand{\labelenumii}{\roman{enumii}.}

% Question numbering
\newcommand{\question}[1]{\section{\textmd{[#1 marks]}}}
\newcommand{\mcquestion}[1]{%
\renewcommand{\thesection}{Multiple Choice Questions}
\renewcommand{\labelenumi}{\arabic{enumi}.}
\renewcommand{\labelenumii}{(\alph{enumii})}
\section{\textmd{[#1 marks]}}
}

% Short title
\renewcommand{\maketitle}{%
\pagestyle{fancy}
\begin{center}
{\huge\textbf{\@coursecode\ -- \@doctitle}\\}
\end{center}
}
